==> kubernetes-model-core-5.12.2-sources.jar: io/fabric8/kubernetes/api/model/ResourceQuotaBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ResourceQuotaBuilder extends io.fabric8.kubernetes.api.model.ResourceQuotaFluentImpl<io.fabric8.kubernetes.api.model.ResourceQuotaBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.ResourceQuota,io.fabric8.kubernetes.api.model.ResourceQuotaBuilder>{
  public ResourceQuotaBuilder() {
    this(false);
  }
  public ResourceQuotaBuilder(java.lang.Boolean validationEnabled) {
    this(new ResourceQuota(), validationEnabled);
  }
  public ResourceQuotaBuilder(io.fabric8.kubernetes.api.model.ResourceQuotaFluent<?> fluent) {
    this(fluent, false);
  }
  public ResourceQuotaBuilder(io.fabric8.kubernetes.api.model.ResourceQuotaFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ResourceQuota(), validationEnabled);
  }
  public ResourceQuotaBuilder(io.fabric8.kubernetes.api.model.ResourceQuotaFluent<?> fluent,io.fabric8.kubernetes.api.model.ResourceQuota instance) {
    this(fluent, instance, false);
  }
  public ResourceQuotaBuilder(io.fabric8.kubernetes.api.model.ResourceQuotaFluent<?> fluent,io.fabric8.kubernetes.api.model.ResourceQuota instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ResourceQuotaBuilder(io.fabric8.kubernetes.api.model.ResourceQuota instance) {
    this(instance,false);
  }
  public ResourceQuotaBuilder(io.fabric8.kubernetes.api.model.ResourceQuota instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.ResourceQuotaFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.ResourceQuota build() {
    ResourceQuota buildable = new ResourceQuota(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ResourceQuotaBuilder that = (ResourceQuotaBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> kubernetes-model-core-6.6.0-sources.jar: io/fabric8/kubernetes/api/model/ResourceQuotaBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ResourceQuotaBuilder extends ResourceQuotaFluentImpl<ResourceQuotaBuilder> implements VisitableBuilder<ResourceQuota,ResourceQuotaBuilder>{
  public ResourceQuotaBuilder() {
    this(false);
  }
  public ResourceQuotaBuilder(Boolean validationEnabled) {
    this(new ResourceQuota(), validationEnabled);
  }
  public ResourceQuotaBuilder(ResourceQuotaFluent<?> fluent) {
    this(fluent, false);
  }
  public ResourceQuotaBuilder(ResourceQuotaFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ResourceQuota(), validationEnabled);
  }
  public ResourceQuotaBuilder(ResourceQuotaFluent<?> fluent,ResourceQuota instance) {
    this(fluent, instance, false);
  }
  public ResourceQuotaBuilder(ResourceQuotaFluent<?> fluent,ResourceQuota instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ResourceQuotaBuilder(ResourceQuota instance) {
    this(instance,false);
  }
  public ResourceQuotaBuilder(ResourceQuota instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  ResourceQuotaFluent<?> fluent;
  Boolean validationEnabled;
  public ResourceQuota build() {
    ResourceQuota buildable = new ResourceQuota(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
